.. _examples:
.. currentmodule:: control

********
Examples
********

The source code for the examples below are available in the `examples/`
subdirecory of the source code distribution.  The can also be accessed online
via the [python-control GitHub repository](https://github.com/python-control/python-control/tree/master/examples).
  

Python scripts
==============

The following Python scripts document the use of a variety of methods in the
Python Control Toolbox on examples drawn from standard control textbooks and
other sources.

.. toctree::
   :maxdepth: 1

   secord-matlab
   pvtol-nested
   pvtol-lqr
   rss-balred
   phaseplots
   robust_siso
   robust_mimo
   cruise-control
   steering-gainsched
   steering-optimal
   kincar-flatsys

Jupyter notebooks
=================

The examples below use `python-control` in a Jupyter notebook environment.
These notebooks demonstrate the use of modeling, anaylsis, and design tools
using running examples in FBS2e.

.. toctree::
   :maxdepth: 1

   cruise
   describing_functions
   kincar-fusion
   mpc_aircraft
   steering
   pvtol-lqr-nested
   pvtol-outputfbk
   stochresp
